function  xinv = invpd(x)
% PURPOSE: inverts matrix using augmented eigenvalues for non PD case
% ----------------------------------------------------------------
% USAGE: xinv = invpd(x)
% where: x    = input matrix
%        xinv = matrix inverse
% NOTES:
% Carries out SVD and augments small eigenvalues, setting them to 0.01
% if they are < eps
% otherwise, used matlab inv() function
% This function is slow, so only use it on small matrices
% Intended to ensure PD var-cov matrices returned by numerical hessian

% Written by:
% James P. LeSage, Dept of Economics
% University of Toledo
% 2801 W. Bancroft St,
% Toledo, OH 43606
% jlesage@spatial-econometrics.com

[n m] = size(x);
[u d v] = svd(x);
dd = diag(d);
if all(dd > eps);
    xinv = inv(x);
else
    dd = dd + 0.01;
    di = ones(n,1)./dd;
    xinv = u*diag(di)*v';
end;